@@ -18,7 +18,7 @@
 #
 # This translation was updated for Oddmuse 1.354.
 #
-$ModulesDescription .= '<p>$Id: bulgarian-utf8.pl,v 1.6 2005/10/09 12:48:35 as Exp $</p>';
+$ModulesDescription .= '<p>$Id: bulgarian-utf8.pl,v 1.8 2006/05/10 22:52:16 as Exp $</p>';
 %Translate = split(/\n/,<<END_OF_TRANSLATION);
 Reading not allowed: user, ip, or network is blocked.
 Не е разрешено четенето: блокиран потребител, IP адрес или мрежа.
@@ -30,6 +30,8 @@ UserName must be 50 characters or less: not saved
 Дължината на потребителското име не трябва да надвишава 50 знака: нищо не бе записано.
 This page contains an uploaded file:
 
+Recursive include of %s!
+
 XML::RSS is not available on this system.
 Модулът XML::RSS не е инсталиран на тази система.
 diff
@@ -60,14 +62,12 @@ Page name is missing
 
 Page name is too long: %s
 Прекалено дълго име на страница: %s
-Invalid Page %s
-Невалидна страница: %s
 Invalid Page %s (must not end with .db)
 Невалидна страница: %s (не може да завършва на .db)
 Invalid Page %s (must not end with .lck)
 Невалидна страница: %s (не може да завършва на .lck)
-Page name may not contain space characters: %s
-Името на страницата не може да съдържа интервали: %s
+Invalid Page %s
+Невалидна страница: %s
 Preview:
 Предварителен преглед:
 Preview only, not yet saved
@@ -220,6 +220,8 @@ s
 
 Save
 Запис
+p
+
 Preview
 Предварителен преглед
 Search:
@@ -276,6 +278,8 @@ Cannot create %s
 
 Could not get %s lock
 Не може да се резервират изключителни права върху %s.
+The lock was created %s.
+
 This operation may take several seconds...
 Тази операция може да потрае малко...
 Forced unlock of %s lock.
@@ -468,8 +472,6 @@ Edit lock removed.
 Защитата от редакции бе премахната.
 Set or Remove page edit lock
 Налагане или отмяна на защита от редакции.
-Missing page id to lock/unlock...
-Липсва идентификатор на страница за налагане/отмяна на защита...
 Lock for %s created.
 Бе наложена защита за %s.
 Lock for %s removed.
@@ -520,6 +522,8 @@ Immediately delete %s
 
 Rename %s to:
 
+Learn more...
+
 Cannot highlight the language %s.
 
 Recent Visitors
@@ -530,7 +534,7 @@ was here
 
 and read
 
-Missing one of cal(1), Date::Calc(3), or Date::Pcalc(3) to produce the calendar.
+Illegal year value: Use 0001-9999
 
 The match parameter is missing.
 
@@ -542,6 +546,44 @@ Next
 
 Calendar %s
 
+Su
+
+Mo
+
+Tu
+
+We
+
+Th
+
+Fr
+
+Sa
+
+January
+
+February
+
+March
+
+April
+
+May
+
+June
+
+July
+
+August
+
+September
+
+October
+
+November
+
+December
+
 Clustermap
 
 Pages without a Cluster
@@ -572,11 +614,9 @@ Footnotes:
 
 Could not find %1.html template in %2
 
-Only Editors are allowed to see hidden pages.
+Only Editors are allowed to see this hidden page.
 
-Only Admins are allowed to see hidden pages.
-
-image: %s
+Only Admins are allowed to see this hidden page.
 
 Index
 
@@ -592,6 +632,10 @@ Template without parameters
 
 The template %s is either empty or does not exist.
 
+ -- defined on %s
+
+Local names defined on %1: %2
+
 Register for %s
 
 Please choose a username of the form "FirstLast" using your real name.
@@ -606,9 +650,9 @@ The username %s has already been registered.
 
 Your registration for %s has been submitted.
 
-  Please allow time for the webmaster to approve your request.
+Please allow time for the webmaster to approve your request.
 
-  An email has been sent to "%s" with further instructions.
+An email has been sent to "%s" with further instructions.
 
 There was an error saving your registration.
 
@@ -622,7 +666,7 @@ Logged in as %s.
 
 Logout of %s
 
-<p>Logout of %s?</p>
+Logout of %s?
 
 Logged out of %s
 
@@ -658,17 +702,17 @@ Reset Password
 
 The password for %s was reset.  It has been emailed to the address on file.
 
-There was an error resetting the password for %s
+There was an error resetting the password for %s.
 
 The username "%s" does not exist.
 
 Reset Password for %s
 
-<p>Reset Password?</p>
+Reset Password?
 
 Change Password for %s
 
-<p>Change Password?</p>
+Change Password?
 
 Your current password is incorrect.
 
@@ -688,6 +732,8 @@ There was an error approving %s.
 
 There are no pending registrations.
 
+%s is not a legal name for a namespace
+
 Clearing Cache
 
 Done.
@@ -720,6 +766,12 @@ Type
 
 Permalink to "%s"
 
+There was an error generating the pdf for %s.  Please report this to webmaster, but do not try to download again as it will not work.
+
+Someone else is generating a pdf for %s.  Please wait a minute and then try again.
+
+Download this page as PDF
+
 Portrait
 
 You did not answer correctly.
@@ -728,9 +780,11 @@ All Referrers
 Всички линкове
 Referrers
 Линкове
+Tag
+
 Rebuild index for searching
 
-Rebuilding Index
+Tag Cloud
 
 Search::FreeText is not available on this system.
 
@@ -738,6 +792,8 @@ Rebuilding index not done.
 
 (Rebuilding the index can only be done once every 12 hours.)
 
+ ... 
+
 Search term missing.
 
 Result pages: 
@@ -754,8 +810,6 @@ Copy to %1 succeeded: %2.
 
 Copy to %1 failed: %2.
 
-Tag
-
 Alternatively, use one of the following templates:
 
 Thread: %s
