@@ -17,7 +17,7 @@
 #
 # This translation was last checked for Oddmuse version 1.504.
 #
-$ModulesDescription .= '<p>$Id: chinese-utf8.pl,v 1.6 2005/10/09 12:48:35 as Exp $</p>';
+$ModulesDescription .= '<p>$Id: chinese-utf8.pl,v 1.8 2006/05/10 22:52:16 as Exp $</p>';
 %Translate = split(/\n/,<<END_OF_TRANSLATION);
 Reading not allowed: user, ip, or network is blocked.
 禁止讀取：使用者、ip 或是網路已被禁止連線。
@@ -29,6 +29,8 @@ UserName must be 50 characters or less: not saved
 無法儲存。使用者名稱不可超過 50 個字元。
 This page contains an uploaded file:
 本頁包含一個已上傳的檔案：
+Recursive include of %s!
+
 XML::RSS is not available on this system.
 本系統無法使用 XML::RSS 。
 diff
@@ -59,14 +61,12 @@ Page name is missing
 頁面不存在
 Page name is too long: %s
 頁面名稱太長了： %s
-Invalid Page %s
-無效的頁面名稱 %s
 Invalid Page %s (must not end with .db)
 無效的頁面名稱 %s (不可使用 .db 做為結尾)
 Invalid Page %s (must not end with .lck)
 無效的頁面名稱 %s (不可使用 .lck 做為結尾)
-Page name may not contain space characters: %s
-頁面名稱不可包含空白字元： %s
+Invalid Page %s
+無效的頁面名稱 %s
 Preview:
 預覽：
 Preview only, not yet saved
@@ -219,6 +219,8 @@ s
 
 Save
 儲存
+p
+
 Preview
 預覽
 Search:
@@ -275,6 +277,8 @@ Cannot create %s
 
 Could not get %s lock
 無法取得 %s 鎖定
+The lock was created %s.
+
 This operation may take several seconds...
 這個動作可能要花幾秒…
 Forced unlock of %s lock.
@@ -467,8 +471,6 @@ Edit lock removed.
 移除編輯鎖定。
 Set or Remove page edit lock
 設定或移除頁面的編輯鎖定
-Missing page id to lock/unlock...
-沒有指定要鎖定/解鎖的頁面名稱 (id)...
 Lock for %s created.
 已建立 %s 的鎖定。
 Lock for %s removed.
@@ -519,6 +521,8 @@ Immediately delete %s
 
 Rename %s to:
 
+Learn more...
+
 Cannot highlight the language %s.
 無法強調顯示 %s 。
 Recent Visitors
@@ -529,8 +533,8 @@ was here
 
 and read
 
-Missing one of cal(1), Date::Calc(3), or Date::Pcalc(3) to produce the calendar.
-缺少下列之一的工具以致無法產生日曆: cal(1), Date::Calc(3), 或 Date::Pcalc(3)
+Illegal year value: Use 0001-9999
+
 The match parameter is missing.
 未指定 match 參數。
 Page Collection for %s
@@ -541,6 +545,44 @@ Next
 向後
 Calendar %s
 %s 年曆
+Su
+
+Mo
+
+Tu
+
+We
+
+Th
+
+Fr
+
+Sa
+
+January
+
+February
+
+March
+
+April
+
+May
+
+June
+
+July
+
+August
+
+September
+
+October
+
+November
+
+December
+
 Clustermap
 
 Pages without a Cluster
@@ -571,12 +613,10 @@ Footnotes:
 註解：
 Could not find %1.html template in %2
 無法在 %2 找到 %1.html 的範本
-Only Editors are allowed to see hidden pages.
+Only Editors are allowed to see this hidden page.
 
-Only Admins are allowed to see hidden pages.
+Only Admins are allowed to see this hidden page.
 
-image: %s
-圖像: %s
 Index
 索引
 Languages:
@@ -591,6 +631,10 @@ Template without parameters
 未指定 template 參數
 The template %s is either empty or does not exist.
 範本 %s 可能為空或不存在。
+ -- defined on %s
+
+Local names defined on %1: %2
+
 Register for %s
 
 Please choose a username of the form "FirstLast" using your real name.
@@ -605,9 +649,9 @@ The username %s has already been registered.
 
 Your registration for %s has been submitted.
 
-  Please allow time for the webmaster to approve your request.
+Please allow time for the webmaster to approve your request.
 
-  An email has been sent to "%s" with further instructions.
+An email has been sent to "%s" with further instructions.
 
 There was an error saving your registration.
 
@@ -621,7 +665,7 @@ Logged in as %s.
 
 Logout of %s
 
-<p>Logout of %s?</p>
+Logout of %s?
 
 Logged out of %s
 
@@ -657,17 +701,17 @@ Reset Password
 
 The password for %s was reset.  It has been emailed to the address on file.
 
-There was an error resetting the password for %s
+There was an error resetting the password for %s.
 
 The username "%s" does not exist.
 
 Reset Password for %s
 
-<p>Reset Password?</p>
+Reset Password?
 
 Change Password for %s
 
-<p>Change Password?</p>
+Change Password?
 
 Your current password is incorrect.
 
@@ -687,6 +731,8 @@ There was an error approving %s.
 
 There are no pending registrations.
 
+%s is not a legal name for a namespace
+
 Clearing Cache
 清除暫存
 Done.
@@ -719,6 +765,12 @@ Type
 類別
 Permalink to "%s"
 永久連結至 "%s"
+There was an error generating the pdf for %s.  Please report this to webmaster, but do not try to download again as it will not work.
+
+Someone else is generating a pdf for %s.  Please wait a minute and then try again.
+
+Download this page as PDF
+
 Portrait
 肖像
 You did not answer correctly.
@@ -727,9 +779,11 @@ All Referrers
 所有的引用者
 Referrers
 引用者
+Tag
+
 Rebuild index for searching
 
-Rebuilding Index
+Tag Cloud
 
 Search::FreeText is not available on this system.
 
@@ -737,6 +791,8 @@ Rebuilding index not done.
 
 (Rebuilding the index can only be done once every 12 hours.)
 
+ ... 
+
 Search term missing.
 
 Result pages: 
@@ -753,8 +809,6 @@ Copy to %1 succeeded: %2.
 
 Copy to %1 failed: %2.
 
-Tag
-
 Alternatively, use one of the following templates:
 或者，使用下列範本之一:
 Thread: %s
