@@ -1,4 +1,4 @@
-# Copyright (C) 2004, 2005  Alex Schroeder <alex@emacswiki.org>
+# Copyright (C) 2004, 2005, 2006  Alex Schroeder <alex@emacswiki.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,9 +16,17 @@
 #    59 Temple Place, Suite 330
 #    Boston, MA 02111-1307 USA
 
-$ModulesDescription .= '<p>$Id: markup.pl,v 1.24 2005/10/14 21:12:55 as Exp $</p>';
+$ModulesDescription .= '<p>$Id: markup.pl,v 1.29 2006/03/11 18:10:43 as Exp $</p>';
 
-use vars qw(%MarkupPairs %MarkupSingles %MarkupLines);
+use vars qw(%MarkupPairs %MarkupSingles %MarkupLines $MarkupQuotes $MarkupQuoteTable);
+
+$MarkupQuotes = 1;
+$MarkupQuoteTable = [["'", "'", '"', '"'], # 0
+		     ['&#x2018;', '&#x2019;', '&#x201d;', '&#x201c;', '&#x2019;'], # 1
+		     ['&#x2039;', '&#x203a;', '&#x00bb;', '&#x00ab;', '&#x2019;'], # 2
+		     ['&#x203a;', '&#x2039;', '&#x00ab;', '&#x00bb;', '&#x2019;'], # 3
+		     ['&#x201a;', '&#x2018;', '&#x201c;', '&#x201e;', '&#x2019;'], # 4
+		    ];
 
 push(@MyRules, \&MarkupRule);
 # The ---- rule in usemod.pl conflicts with the --- rule
@@ -135,6 +143,23 @@ sub MarkupRule {
     return '~/'; # fix ~/elisp/ example
   } elsif ($MarkupPairs{'/'} and m|\G(/[-A-Za-z0-9\x80-\xff/]+/$words/)|gc) {
     return $1; # fix /usr/share/lib/! example
+  } elsif ($MarkupQuotes and (m/\G(?<=[[:space:]])"/cg
+			      or pos == 0 and m/\G"/cg)) {
+    return $MarkupQuoteTable->[$MarkupQuotes]->[3];
+  } elsif ($MarkupQuotes and (m/\G"(?=[[:space:][:punct:]])/cg
+			      or m/\G"\z/cg)) {
+    return $MarkupQuoteTable->[$MarkupQuotes]->[2];
+  } elsif ($MarkupQuotes and (m/\G(?<=[[:punct:]])"/cg)) {
+    return $MarkupQuoteTable->[$MarkupQuotes]->[3];
+  } elsif ($MarkupQuotes and pos == 0 and m/\G'/cg) {
+    return $MarkupQuoteTable->[$MarkupQuotes]->[0];
+  } elsif ($MarkupQuotes and (m/\G'(?=[[:space:][:punct:]])/cg
+			      or m/\G'\z/cg)) {
+    return $MarkupQuoteTable->[$MarkupQuotes]->[1];
+  } elsif ($MarkupQuotes and m/\G(?<![[:space:][:punct:]])'/cg) {
+    return $MarkupQuoteTable->[$MarkupQuotes]->[4];
+  } elsif ($MarkupQuotes and m/\G(?<=[[:space:][:punct:]])'/cg) {
+    return $MarkupQuoteTable->[$MarkupQuotes]->[0];
   }
   return undef;
 }
