@@ -1,4 +1,4 @@
-# Copyright (C) 2004, 2005  Alex Schroeder <alex@emacswiki.org>
+# Copyright (C) 2004, 2005, 2006  Alex Schroeder <alex@emacswiki.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,9 +16,9 @@
 #    59 Temple Place, Suite 330
 #    Boston, MA 02111-1307 USA
 
-$ModulesDescription .= '<p>$Id: referrer-tracking.pl,v 1.4 2005/10/09 00:55:43 as Exp $</p>';
+$ModulesDescription .= '<p>$Id: referrer-tracking.pl,v 1.8 2006/04/02 19:48:53 as Exp $</p>';
 
-## == Setup ==
+use LWP::UserAgent;
 
 push(@KnownLocks, "refer_*");
 
@@ -113,12 +113,33 @@ sub ExpireReferers { # no need to save the pruned list if nothing else changes
   }
 }
 
+# maybe test for valid utf-8 later?
+
+# http://www.w3.org/International/questions/qa-forms-utf-8
+
+# $field =~
+#   m/^(
+#      [\x09\x0A\x0D\x20-\x7E]            # ASCII
+#    | [\xC2-\xDF][\x80-\xBF]             # non-overlong 2-byte
+#    |  \xE0[\xA0-\xBF][\x80-\xBF]        # excluding overlongs
+#    | [\xE1-\xEC\xEE\xEF][\x80-\xBF]{2}  # straight 3-byte
+#    |  \xED[\x80-\x9F][\x80-\xBF]        # excluding surrogates
+#    |  \xF0[\x90-\xBF][\x80-\xBF]{2}     # planes 1-3
+#    | [\xF1-\xF3][\x80-\xBF]{3}          # planes 4-15
+#    |  \xF4[\x80-\x8F][\x80-\xBF]{2}     # plane 16
+#   )*$/x;
+
 sub GetReferers {
   my $result = join(' ', map {
     my $title = QuoteHtml($_);
-    $title =~ s/\%([0-9a-f][0-9a-f])/chr(hex($1))/egi;
-    $q->a({-href=>$_}, $title); } keys %Referers);
-  return $q->div({-class=>'refer'}, $q->hr(), $q->p(T('Referrers') . ': ' . $result)) if $result;
+    $title = $1 if $title =~ /$FullUrlPattern/; # extract valid URL
+    my ($ts, $charset) = split(/ /, $Referers{$_});
+    $title =~ s/\%([0-9a-f][0-9a-f])/chr(hex($1))/egi
+      if lc($charset) eq lc($HttpCharset); # decode if possible
+    $q->a({-href=>$_}, $title);
+  } keys %Referers);
+  return $q->div({-class=>'refer'}, $q->hr(), $q->p(T('Referrers') . ': ' . $result))
+    if $result;
 }
 
 sub UpdateReferers {
@@ -131,9 +152,11 @@ sub UpdateReferers {
       return  if $referer =~ /$regexp/i;
     }
   }
-  my $data = GetRaw($referer);
-  return  unless $data =~ /$self/;
-  $Referers{$referer} = $Now;
+  my $ua = LWP::UserAgent->new;
+  my $response = $ua->get($referer);
+  return unless $response->is_success and $response->content =~ /$self/;
+  my ($charset) = $response->header("Content-Type") =~ /charset=([^\s";]*)/;
+  $Referers{$referer} = "$Now $charset"; # numerical comparisons still work!
   return 1;
 }
 
