@@ -4,9 +4,8 @@
 # Copyright (c) 2003 Erik S-O Johansson and others
 # Copyright (c) 2003 Björn Lindström <bkhl@elektrubadur.se> and
 #                    Zrajm C Akfohg <zrajm@klingonska.org>
-# Copyright (c) 2004 Johan Adler <alltid@nyfiken.org>
-# Copyright (c) 2004 Zrajm C Akfohg <zrajm@klingonska.org
-# Copyright (c) 2005 Johan Adler <alltid@nyfiken.org>
+# Copyright (c) 2004-06 Johan Adler <alltid@nyfiken.org>
+# Copyright (c) 2004 Zrajm C Akfohg <zrajm@klingonska.org>
 #
 # Permission is granted to copy, distribute and/or modify this
 # document under the terms of the GNU Free Documentation License,
@@ -21,7 +20,7 @@
 # Create a modules subdirectory in your data directory, and put the
 # file in there. It will be loaded automatically.
 #
-$ModulesDescription .= '<p>$Id: swedish-utf8.pl,v 1.13 2005/10/09 12:48:35 as Exp $</p>';
+$ModulesDescription .= '<p>$Id: swedish-utf8.pl,v 1.15 2006/05/10 22:52:16 as Exp $</p>';
 %Translate = split(/\n/,<<END_OF_TRANSLATION);
 Reading not allowed: user, ip, or network is blocked.
 Läsning inte tillåten: användare, ip eller nätverk är blockerat.
@@ -33,6 +32,8 @@ UserName must be 50 characters or less: not saved
 Användarnamn får bestå av högst 50 tecken: Ej sparad.
 This page contains an uploaded file:
 Denna sida innehåller en uppladdad fil:
+Recursive include of %s!
+
 XML::RSS is not available on this system.
 XML::RSS inte tillgängligt på det här systemet.
 diff
@@ -54,7 +55,7 @@ bild
 download
 ladda ned
 CGI Internal error: %s
-
+Internt CGI-fel: %s
 Invalid action parameter %s
 Ogiltig parameter %s
 Invalid URL.
@@ -63,14 +64,12 @@ Page name is missing
 Sidnamn saknas
 Page name is too long: %s
 Sidnamn är för långt: %s
-Invalid Page %s
-Ogiltig sida %s
 Invalid Page %s (must not end with .db)
 Ogiltig sida %s (får inte sluta med .db)
 Invalid Page %s (must not end with .lck)
 Ogiltig sida %s (får inte sluta med .lck)
-Page name may not contain space characters: %s
-Sidans namn får inte innehålla mellanslag: %s
+Invalid Page %s
+Ogiltig sida %s
 Preview:
 Förhandsgranskning:
 Preview only, not yet saved
@@ -110,9 +109,9 @@ Visa senare ändringar
 Filters
 Sålla
 Title:
-
+Titel:
 Title and Body:
-
+Titel och innehåll:
 Username:
 Användare:
 Host:
@@ -130,7 +129,7 @@ ny
 from %s
 från %s
 This page is too big to send over RSS.
-
+Denna sida är för stor för att sändas över RSS.
 History of %s
 Historik för %s
 Compare
@@ -164,7 +163,7 @@ Lås upp wikin
 Lock site
 Lås wikin
 Install CSS
-
+Installera CSS
 Unlock %s
 Lås upp %s
 Lock %s
@@ -223,6 +222,8 @@ s
 s
 Save
 Spara
+p
+f
 Preview
 Förhandsgranska
 Search:
@@ -250,7 +251,7 @@ mindre
 No diff available.
 Information om ändring är inte tillgänglig.
 The two revisions are the same.
-
+De två versionerna är identiska.
 Old revision:
 Gammal version:
 Changed:
@@ -279,6 +280,8 @@ Cannot create %s
 Kan inte skapa %s
 Could not get %s lock
 Kunde inte låsa %s
+The lock was created %s.
+Låset skapades %s.
 This operation may take several seconds...
 Den här funktionen kan ta flera sekunder...
 Forced unlock of %s lock.
@@ -290,13 +293,13 @@ för %s timmar sedan
 1 hour ago
 för 1 timme sedan
 %s minutes ago
-%s minuter sedan
+för %s minuter sedan
 1 minute ago
-1 minut sedan
+för 1 minut sedan
 %s seconds ago
-%s sekunder sedan
+för %s sekunder sedan
 1 second ago
-1 sekund sedan
+för 1 sekund sedan
 just now
 just nu
 Edit Denied
@@ -312,7 +315,7 @@ Se %s för mer information.
 Editing not allowed: %s is read-only.
 Redigering är inte tillåten: %s är skrivskyddad.
 Only administrators can upload files.
-Bara administratörer kan ladda upp filer.
+Endast administratörer kan ladda upp filer.
 Editing revision %s of
 Redigerar version %s av
 Editing %s
@@ -416,7 +419,7 @@ Webbläsare rapporterar ingen filtyp.
 The page contains banned text.
 Sidan innehåller otillåten text.
 No changes to be saved.
-
+Inga ändringar att spara.
 This page was changed by somebody else %s.
 Den här sidan ändrades av någon annan %s.
 The changes conflict.  Please check the page again.
@@ -471,8 +474,6 @@ Edit lock removed.
 Redigeringslås avslaget.
 Set or Remove page edit lock
 Slå på eller av sidredigeringslås
-Missing page id to lock/unlock...
-Saknar sid-id, kan inte slå på eller av redigeringslås...
 Lock for %s created.
 Slog på redigeringslås för %s.
 Lock for %s removed.
@@ -494,13 +495,13 @@ Vänligen hämta inte mer än %1 sidor på %2 sekunder.
 Check whether the web server can create the directory %s and whether it can create files in it.
 Kontrollera att webservern kan skapa biblioteket %s och att den kan skapa filer i det.
 anchor first defined here: %s
-ankare definierades här först: %s
+ankare definierades först här: %s
 Click to search for references to this permanent anchor
 Klicka för att söka efter referenser till det här permanenta ankaret
 the page %s also exists
 sidan %s finns också
 Copy one of the following stylesheets to %s:
-
+Kopiera en av följande 'stylesheets' till %s:
 Deleting %s
 Tar bort %s
 Deleted %s
@@ -523,18 +524,20 @@ Immediately delete %s
 Radera %s direkt
 Rename %s to:
 Byt namn på %s till:
+Learn more...
+Läs mer...
 Cannot highlight the language %s.
 Kan ej markera språket %s.
 Recent Visitors
 Senaste besökare
 some action
-
+gjorde något
 was here
-
+var här
 and read
+och läste
+Illegal year value: Use 0001-9999
 
-Missing one of cal(1), Date::Calc(3), or Date::Pcalc(3) to produce the calendar.
-Saknar en av cal(1), Date::Calc(3), eller Date::Pcalc(3) för att kunna skapa kalendern.
 The match parameter is missing.
 Parametern "match" saknas.
 Page Collection for %s
@@ -545,10 +548,48 @@ Next
 Nästa
 Calendar %s
 Kalender %s
+Su
+Sö
+Mo
+Må
+Tu
+Ti
+We
+On
+Th
+To
+Fr
+
+Sa
+Lö
+January
+januari
+February
+februari
+March
+mars
+April
+april
+May
+maj
+June
+juni
+July
+juli
+August
+augusti
+September
+september
+October
+oktober
+November
+november
+December
+december
 Clustermap
-
+Klusterkarta
 Pages without a Cluster
-
+Sidor utan kluster
 Comments on 
 Kommentarer till 
 Comment on 
@@ -568,19 +609,17 @@ Markerad som %s.
 Cannot find unspammed revision.
 Kan inte finna version utan skräptexter
 Add Comment
-
+Lägg till kommentar
 ordinary changes
-
+vanliga ändringar
 Footnotes:
 Fotnoter:
 Could not find %1.html template in %2
 Kunde inte finna %1.html-mallen i %2
-Only Editors are allowed to see hidden pages.
+Only Editors are allowed to see this hidden page.
 
-Only Admins are allowed to see hidden pages.
+Only Admins are allowed to see this hidden page.
 
-image: %s
-bild: %s
 Index
 Innehållsförteckning
 Languages:
@@ -595,6 +634,10 @@ Template without parameters
 Mall utan parametrar
 The template %s is either empty or does not exist.
 Mallen %s är antingen tom eller saknas.
+ -- defined on %s
+ -- definierad på %s
+Local names defined on %1: %2
+Lokala namn definierade på %1: %2
 Register for %s
 
 Please choose a username of the form "FirstLast" using your real name.
@@ -609,9 +652,9 @@ The username %s has already been registered.
 
 Your registration for %s has been submitted.
 
-  Please allow time for the webmaster to approve your request.
+Please allow time for the webmaster to approve your request.
 
-  An email has been sent to "%s" with further instructions.
+An email has been sent to "%s" with further instructions.
 
 There was an error saving your registration.
 
@@ -625,7 +668,7 @@ Logged in as %s.
 
 Logout of %s
 
-<p>Logout of %s?</p>
+Logout of %s?
 
 Logged out of %s
 
@@ -661,17 +704,17 @@ Reset Password
 
 The password for %s was reset.  It has been emailed to the address on file.
 
-There was an error resetting the password for %s
+There was an error resetting the password for %s.
 
 The username "%s" does not exist.
 
 Reset Password for %s
 
-<p>Reset Password?</p>
+Reset Password?
 
 Change Password for %s
 
-<p>Change Password?</p>
+Change Password?
 
 Your current password is incorrect.
 
@@ -691,6 +734,8 @@ There was an error approving %s.
 
 There are no pending registrations.
 
+%s is not a legal name for a namespace
+
 Clearing Cache
 Rensar cachen
 Done.
@@ -723,6 +768,12 @@ Type
 Sort
 Permalink to "%s"
 Permanentlänk till "%s"
+There was an error generating the pdf for %s.  Please report this to webmaster, but do not try to download again as it will not work.
+
+Someone else is generating a pdf for %s.  Please wait a minute and then try again.
+
+Download this page as PDF
+
 Portrait
 Porträtt
 You did not answer correctly.
@@ -731,9 +782,11 @@ All Referrers
 Alla som länkat hit
 Referrers
 Sidor som länkat hit
+Tag
+
 Rebuild index for searching
 
-Rebuilding Index
+Tag Cloud
 
 Search::FreeText is not available on this system.
 
@@ -741,6 +794,8 @@ Rebuilding index not done.
 
 (Rebuilding the index can only be done once every 12 hours.)
 
+ ... 
+
 Search term missing.
 Sökord saknas.
 Result pages: 
@@ -757,8 +812,6 @@ Copy to %1 succeeded: %2.
 
 Copy to %1 failed: %2.
 
-Tag
-
 Alternatively, use one of the following templates:
 Eller använd en av följande mallar:
 Thread: %s
