@@ -16,7 +16,7 @@
 #    59 Temple Place, Suite 330
 #    Boston, MA 02111-1307 USA
 
-$ModulesDescription .= '<p>$Id: toc.pl,v 1.28 2005/12/08 12:42:36 as Exp $</p>';
+$ModulesDescription .= '<p>$Id: toc.pl,v 1.32 2006/05/26 07:48:33 as Exp $</p>';
 
 push(@MyRules, \&TocRule);
 
@@ -46,12 +46,13 @@ sub TocRule {
 	   && m/\G(\s*\n)*(\=+)[ \t]*(?=[^=\n]+=)/cg) {
     my $depth = length($2);
     $depth = 6 if $depth > 6;
+    $depth = 2 if $depth < 2;
     my $html = CloseHtmlEnvironments()
       . ($PortraitSupportColorDiv ? '</div>' : '');
     $html .= TocHeadings() if not $TocShown and $TocAutomatic;
     $TocShown = 1 if $TocAutomatic;
-    $html .= AddHtmlEnvironment('h' . $depth)
-      . $q->a({-id=>$key . ++$TocCounter{$key}}, '');
+    my $TocKey = $key . ++$TocCounter{$key};
+    $html .= AddHtmlEnvironment('h' . $depth, qq{id="$TocKey"});
     $PortraitSupportColorDiv = 0; # after the HTML has been determined.
     $PortraitSupportColor = 0;
     return $html;
@@ -69,14 +70,14 @@ sub TocRule {
 	   && m/\G(\s*\n)*(\=+)[ \t]*(.+?)[ \t]*(=+)[ \t]*\n?/cg) {
     my $depth = length($2);
     $depth = 6 if $depth > 6;
+    $depth = 2 if $depth < 2;
     my $text = $3;
     my $html = CloseHtmlEnvironments()
       . ($PortraitSupportColorDiv ? '</div>' : '');
     $html .= TocHeadings() if not $TocShown and $TocAutomatic;
     $TocShown = 1 if $TocAutomatic;
-    $html .= "<h$depth>"
-      . $q->a({-id=>$key . ++$TocCounter{$key}}, $text)
-      . "</h$depth>"
+    my $TocKey = $key . ++$TocCounter{$key};
+    $html .= qq{<h$depth id="$TocKey">$text</h$depth>}
       . AddHtmlEnvironment('p');
     $PortraitSupportColorDiv = 0; # after the HTML has been determined.
     $PortraitSupportColor = 0;
@@ -89,20 +90,28 @@ sub TocHeadings {
   my $oldpos = pos;          # make this sub not destroy the value of pos
   my $page = $Page{text};   # work on the page that is currently open!
   # ignore all the stuff that gets processed anyway
-  foreach my $tag ('nowiki', 'pre', 'code') {
-    $page =~ s|<$tag>(.*\n)*?</$tag>||gi;
-  }
+  $page =~ s!<nowiki>.*?</nowiki>!!gis if defined &UsemodRule;
+  $page =~ s!<code>.*?</code>!!gis if defined &UsemodRule;
+  $page =~ s!(^|\n)<pre>.*?</pre>!!gis if defined &UsemodRule;
+  $page =~ s!##.*?##!!gis if defined &MarkupRule;
+  $page =~ s!%%.*?%%!!gis if defined &MarkupRule;
   my $Headings           = "<h2>" . T('Contents') . "</h2>";
   my $HeadingsLevel      = undef;
   my $HeadingsLevelStart = undef;
   my $count              = 1;
   # try to determine what will end up as a header
-  foreach my $line (grep(/^\=+.*\=+[ \t]*$/, split(/\n/, $page))) {
-    next unless $line =~ /^(\=+)[ \t]*(.*?)[ \t]*\=+[ \t]*$/;
-    my $depth = length($1);
-    my $text  = $2;
+  foreach my $line (grep(/^(=|<h\d>)/, split(/\n/, $page))) {
+    my ($depth, $text, $link);
+    if ($line =~ /^(\=+)[ \t]*(.*?)[ \t]*\=+[ \t]*$/) {
+      $depth = length($1);
+      $link = ($OpenPageName||'toc') . $count;
+      $text  = $2;
+    } elsif ($line =~ /^<h(\d)><a id\="(.+)">[ \t]*(.*?)[ \t]*<\/a><\/h\1>[ \t]*$/) {
+      $depth = $1;
+      $link  = $2;
+      $text  = $3;
+    }
     next unless $text;
-    my $link = ($OpenPageName||'toc') . $count;
     $text = QuoteHtml($text);
     if (not defined $HeadingsLevelStart) {
       # $HeadingsLevel is set to $depth - 1 so that we get an opening
